<?php

/*
  Current known FCC address ranges:
  https://news.ycombinator.com/item?id=7716915

*/

class SlowLanePlugin {

  public $pluginDir;
  public $targetCIDRS;

  public function __construct()
  {
     $this->targetCIDRS = array(  
                                  '192.133.125.0/24', 
                                  '165.135.0.0/16',
                                  '192.104.54.0/24',
                                  '4.21.126.0/24',
                                  '65.125.25.64/26',
                                  '208.23.64.0/25',
                                  '208.31.254.128/25'
                               );
  }

  public function setPluginDir($dir)
  {
      $this->pluginDir = $dir;
  }
  
  public function init()
  {
     if(!session_id()) {
       session_start();
      }

      if ($cmd = $_REQUEST['fcc'])
      {
         $cmd = strtoupper($cmd);
         switch($cmd)
         {
            case 'DEMO-ON'        : $_SESSION['fcc_demo'] = 'YES'; break;
            case 'DEMO-OFF'       : $_SESSION['fcc_demo'] = 'NO'; break;
            case 'SHOW-FCC-CIDRS' : $this->showBlockedCIDRS(); break;
         }
      }

      if ($this->isTargetIP() || $_SESSION['fcc_demo'] == 'YES')
      {
         $this->render('fcc', $data);
         sleep(2);
      }
  }

  private function showBlockedCIDRS()
  {
     $data['cidrs'] = $this->targetCIDRS;
     $this->render('fcc', $data);
     exit;
  }

  private function isTargetIP()
  {
     $found = false;
     $ip    = $_SERVER['REMOTE_ADDR'];

     $ipu   = explode('.', $ip);

     foreach ($ipu as &$v)
     {
        $v = str_pad(decbin($v), 8, '0', STR_PAD_LEFT);
     }

     $ipu = join('', $ipu);

     foreach ($this->targetCIDRS as $thisCIDR) 
     {
       $parts = explode('/', $thisCIDR);
       $ipc   = explode('.', $parts[0]);

       foreach ($ipc as &$v) 
       {
          $v = str_pad(decbin($v), 8, '0', STR_PAD_LEFT);
       }

       $ipc  = substr(join('', $ipc), 0, $parts[1]);
       $ipux = substr($ipu, 0, $parts[1]);

       $found = ($ipc === $ipux);

       if ($found) return true;
    }

    return false;
  }

  private function render($template, $data, $showOutput = true)
  {
     if (!$this->pluginDir)
     {
         die("Set \$this->pluginDir for your plugin before calling render().");
     }

     $data['pluginPrefix'] = $this->prefix;

     extract($data);

     ob_start();

     $viewDir = $this->pluginDir . 'views';
     $viewFile = $viewDir . '/' . $template . '.php';

     if (file_exists($viewFile))
     {
        include($viewFile);
     } else {
       die("Missing $viewFile");
     }
 
     $output = ob_get_clean();
     if ($showOutput) {
         echo $output;
     } else {
        return $output;
     }
  }
  
  public function activate()
  {     
  }   
  
  public function deactivate()
  {
  }

  public function d($r, $f = null)
  {
     echo '<pre>';
     print_r($r);
     echo '</pre>';
     
     if($f) exit;
  }
} // End of class


?>
